import { HiroColors } from '../../types';
export declare type Widgets = 'Welcome' | 'IssueList' | 'SessionList' | 'UserStats' | 'AutomationStats';
export declare type SupportedDataTypes = 'string' | 'task';
export interface TaskData<T = any> {
    loading: boolean;
    start: number;
    finish: number;
    error: false | {
        message: string;
        code: number;
        isRetryable: boolean;
    };
    result?: T;
}
/**
 * Basic Widget config
 */
export interface BaseWidgetConfig {
    size?: number | number[];
    title?: string;
    content?: string | number;
    as?: Widgets;
}
/**
 * Advanced Widget config with automatic data loading
 */
export interface WidgetDataConfig {
    path: string | string[];
    type: SupportedDataTypes;
    fallback?: string;
}
export interface DataWidgetConfig extends BaseWidgetConfig {
    data?: WidgetDataConfig;
}
/**
 * Widgets
 */
export interface SimpleWidgetConfig extends BaseWidgetConfig {
    as?: undefined;
}
export interface WelcomeWidgetConfig extends BaseWidgetConfig {
    as?: 'Welcome';
}
export interface IssueListWidgetConfig extends DataWidgetConfig {
    as: 'IssueList';
}
export interface SessionListWidgetConfig extends DataWidgetConfig {
    as: 'SessionList';
}
export interface UserStatsWidgetConfig extends DataWidgetConfig {
    as: 'UserStats';
}
export interface AutomationStatsWidgetConfig extends DataWidgetConfig {
    as: 'AutomationStats';
}
export declare type WidgetConfig = SimpleWidgetConfig | WelcomeWidgetConfig | IssueListWidgetConfig | SessionListWidgetConfig;
export interface DashboardConfig {
    store?: string | string[];
    color?: HiroColors;
    widgets?: Record<string, WidgetConfig>;
}
