import { useMemo, lazy } from 'react';
/**
 * Async component loading for use with Dashboard.
 *
 * Should be used with component wrapped in `React.Suspense`
 *
 * @example
 * ```
 * const AsyncHeader = () => {
 *  const Header = useAsyncComponent('Header');
 *
 *  return <Header>Hello world!</Header>
 * }
 *
 * ...
 *
 * <React.Suspense fallback={<Loader active />}>
 *   <AsyncHeader />
 * </React.Suspense>
 * ```
 */
export var useWidget = function (type) {
    return useMemo(function () {
        switch (type) {
            case 'IssueList':
                return lazy(function () { return import('./IssueList'); });
            case 'SessionList':
                return lazy(function () { return import('./SessionList'); });
            case 'Welcome':
                return lazy(function () { return import('./Welcome'); });
            case 'UserStats':
                return lazy(function () { return import('./UserStats'); });
            case 'AutomationStats':
                return lazy(function () { return import('./AutomationStats'); });
            default:
                if (type) {
                    console.warn("Async component '" + type + "' not supported");
                }
                return lazy(function () { return import('../../elements/Flex/Box'); });
        }
    }, [type]);
};
