import { CSSObject, StyledComponent, StyledComponentProps } from 'styled-components';
export declare type GetProps<Component> = Component extends StyledComponent<infer C, infer T, infer O, infer A> ? StyledComponentProps<C, T, O, A> : any;
declare type ExtraPartial<T> = {
    [P in keyof T]?: T[P] extends Record<infer K, infer U> ? Partial<T[P]> : T[P];
};
export declare type HiroColors = 'primary' | 'secondary' | 'primaryText' | 'secondaryText' | 'red' | 'orange' | 'yellow' | 'green' | 'teal' | 'blue' | 'purple' | 'pink' | 'brown' | 'black' | 'grey' | 'white';
export declare type Greyscales = 'lighter' | 'light' | 'medium' | 'dark' | 'darker' | 'darkest';
export interface BreakpointDefinitions {
    md: number;
    lg: number;
    xl: number;
}
export interface ColorDefinitionValues {
    default: string;
    active: string;
    hover: string;
    light: string;
    dark: string;
    verylight: string;
}
export declare type SizeScale = 'mini' | 'tiny' | 'small' | 'medium' | 'large' | 'big' | 'huge' | 'massive';
export declare type ColorDefinitions = Record<HiroColors, ColorDefinitionValues>;
export interface FontDefinitons {
    h1: CSSObject;
    h2: CSSObject;
    h3: CSSObject;
}
export declare type GreyscaleDefinitions = {
    [K in Greyscales]: string;
};
export interface SizeDefinitions {
    borderRadius: string | number;
    padding: Record<'normal' | 'extra', string>;
    scale: Record<SizeScale, string | number>;
}
export interface HiroDefaultTheme {
    breakpoints: BreakpointDefinitions;
    colors: Record<HiroColors, string>;
    font: FontDefinitons;
    global: CSSObject;
    greyscale: GreyscaleDefinitions;
    sizes: SizeDefinitions;
}
export interface HiroPartialTheme {
    breakpoints?: ExtraPartial<BreakpointDefinitions>;
    colors?: ExtraPartial<Record<HiroColors, string>>;
    font?: ExtraPartial<FontDefinitons>;
    global?: CSSObject;
    greyscale?: ExtraPartial<GreyscaleDefinitions>;
    sizes?: ExtraPartial<SizeDefinitions>;
}
declare module 'styled-components' {
    interface DefaultTheme {
        breakpoints: BreakpointDefinitions;
        colors: ColorDefinitions;
        font: FontDefinitons;
        global: CSSObject;
        greyscale: GreyscaleDefinitions;
        sizes: SizeDefinitions;
    }
}
export {};
