import { createTheme } from '../theme';
import { flexbox, alignRow, alignColumn } from './flex';
var theme = createTheme({
    breakpoints: {
        md: 100,
        lg: 200,
        xl: 300,
    },
});
function checkBreakpoints(res, expected) {
    expect(res['@media only screen and (max-width: 99px)']).toEqual({
        flexBasis: expected[0],
    });
    expect(res['@media only screen and (max-width: 199px) and (min-width: 100px)']).toEqual({
        flexBasis: expected[1],
    });
    expect(res['@media only screen and (max-width: 299px) and (min-width: 200px)']).toEqual({
        flexBasis: expected[2],
    });
    expect(res['@media only screen and (min-width: 300px)']).toEqual({
        flexBasis: expected[3],
    });
}
describe('flexbox', function () {
    it('Empty style', function () {
        var res = flexbox({ theme: theme });
        expect(res).toBeFalsy();
    });
    it('Accept one value', function () {
        var res = flexbox({ theme: theme, size: 0.5 });
        expect(res).toBeTruthy();
        checkBreakpoints(res, ['100%', '50%', '50%', '50%']);
    });
    it('Accept two values', function () {
        var res = flexbox({ theme: theme, size: [0.5, 0.6] });
        expect(res).toBeTruthy();
        checkBreakpoints(res, ['50%', '60%', '60%', '60%']);
    });
    it('Accept all values', function () {
        var res = flexbox({ theme: theme, size: [0.5, 0.6, 0.7, 0.8] });
        expect(res).toBeTruthy();
        checkBreakpoints(res, ['50%', '60%', '70%', '80%']);
    });
    it('Force minimum value', function () {
        var res = flexbox({ theme: theme, size: -1 });
        expect(res).toBeTruthy();
        checkBreakpoints(res, ['100%', '0%', '0%', '0%']);
    });
    it('Force maximum value', function () {
        var res = flexbox({ theme: theme, size: 2 });
        expect(res).toBeTruthy();
        checkBreakpoints(res, ['100%', '100%', '100%', '100%']);
    });
});
describe('alignRow', function () {
    it('Default', function () {
        var res = alignRow({});
        expect(res).toBeTruthy();
        expect(res).toEqual({ width: '100%' });
    });
    it('Set vertical align', function () {
        var res = alignRow({ verticalAlign: 'center' });
        expect(res).toBeTruthy();
        expect(res.alignItems).toBe('center');
    });
    it('Set floated', function () {
        var res = alignRow({ floated: 'left' });
        expect(res).toBeTruthy();
        expect(res.marginRight).toBe('auto');
    });
    it('Set centered', function () {
        var res = alignRow({ centered: true });
        expect(res).toBeTruthy();
        expect(res.justifyContent).toBe('center');
    });
});
describe('alignColumn', function () {
    it('Empty', function () {
        var res = alignColumn({ verticalAlign: 'center' });
        expect(res).toBeTruthy();
        expect(res.justifyContent).toBe('center');
    });
    it('Set floated', function () {
        var res = alignColumn({ floated: 'left' });
        expect(res).toBeTruthy();
        expect(res.marginRight).toBe('auto');
    });
    it('Set centered', function () {
        var res = alignColumn({ centered: true });
        expect(res).toBeTruthy();
        expect(res.alignItems).toBe('center');
    });
});
